from models.graph import Graph
from models.point import Point
from models.triangle import Triangle

class Kirkpatrick:
    def __init__(self, g: Graph):
        pass

    def locate_point(self, dot: Point):
        pass

